﻿using System;
using System.Collections.Generic;
using System.Linq;
using System.Text;
using System.ComponentModel;
using StackedColumnSeriesHelp.Repositories;
using System.Collections.ObjectModel;
using StackedColumnSeriesHelp.Models;

namespace StackedColumnSeriesHelp.ViewModels
{
    class MainWindowViewModel : INotifyPropertyChanged
    {
        #region Fields
        int? _selectedIndex;
        ObservableCollection<DataModel> _histogramSeries;
        #endregion //Fields

        #region Constructor
        public MainWindowViewModel()
        {
        }
        #endregion //Constructor

        #region Properties
        public int SelectedIndex
        {
            get
            {
                if (_selectedIndex == null)
                    _selectedIndex = 0;
                return (int)_selectedIndex;
            }
            set
            {
                _selectedIndex = value;
                LoadData();
                ChangeTitle();
                OnPropertyChanged("SelectedIndex");
            }
        }

        public string SeriesTitle
        {
            get
            {
                return Items.ElementAt(SelectedIndex);
            }
        }

        public string SeriesTitleValues
        {
            get
            {
                return SeriesTitle + " Values";
            }
        }

        public string SeriesTitleErrors
        {
            get
            {
                return SeriesTitle + " Errors";
            }
        }

        public List<string> Items
        {
            get
            {
                return ItemsRepository.Items.ToList<string>();
            }
        }

        public ObservableCollection<DataModel> HistogramSeries
        {
            get
            {
                if (_histogramSeries == null)
                    _histogramSeries = DataRepository.GetDataByID(SelectedIndex);
                return _histogramSeries;
            }
            set
            {
                _histogramSeries = value;
                OnPropertyChanged("HistogramSeries");
            }
        }
        #endregion //Properties

        #region Helpers
        private void LoadData()
        {
            HistogramSeries = DataRepository.GetDataByID(SelectedIndex);
        }
        private void ChangeTitle()
        {
            OnPropertyChanged("SeriesTitle");
            OnPropertyChanged("SeriesTitleValues");
            OnPropertyChanged("SeriesTitleError");
        }
        #endregion //Helpers

        #region INotifyPropertyChanged
        public event PropertyChangedEventHandler PropertyChanged;
        public void OnPropertyChanged(string propertyName)
        {
            if (PropertyChanged != null)
            {
                PropertyChanged(this, new PropertyChangedEventArgs(propertyName));
            }
        }
        #endregion //INotifyPropertyChanged
    }
}
